#!/usr/bin/perl
# bf2.pl
# 01.19.2009
# Browser Fuzzer 2
#
#       Krakow Labs Development [krakowlabs.com] -> bf2
#     "Browser Fuzzer 2 -- The bugs cannot hide anymore"
#        rush@KL (Jeremy Brown) [rush@krakowlabs.com]
#
# Associated Files & Information:
# http://www.krakowlabs.com/dev/fuz/bf2/bf2.pl.txt
# http://www.krakowlabs.com/dev/fuz/bf2/bf2_doc.txt
# http://www.krakowlabs.com/dev/fuz/bf2/bf2.tar.gz
# http://www.krakowlabs.com/dev/fuz/bf2/bf2.jpeg
# bf2.pl

use Getopt::Std;

# FUZZ DATA BEGIN HERE [_Jeremy Brown_ 3rd Generation Fuzzing Oracle [unlimited style, web] _Jeremy Brown_] 116
@overflows = ('A' x 2200, 'A' x 4200, 'A' x 8500, 'A' x 12000, 'A' x 22000, 'A' x 52000, 'A' x 120000, 'A' x 500500,
	      'A' x 1200000, 'A' x 5005000, 'A' x 12000000, 'A' x 20000000, '//AAAA' x 5000, '\\\AAAA' x 5000, '\0x99' x 12000,
	      'http://' . 'A' x 4200, 'http://' . 'A' x 12000, 'http://' . 'A' x 500500, 'http://' . 'A' x 5005000, 'http://' . 'A' x 20000000,
	      'www.' . 'A' x 4200 . '.com', 'www.' . 'A' x 12000 . '.com', 'www.' . 'A' x 500500 . '.com', 'www.' . 'A' x 5005000 . '.com', 'www.' . 'A' x 20000000 . '.com',
	      'A/' x 2100, 'A/' x 6000, 'A/' x 250250, 'A/' x 2502500, 'A/' x 10000000); # 30

@fmtstring = ('%n%n%n%n%n', '%p%p%p%p%p', '%s%s%s%s%s', '%d%d%d%d%d', '%x%x%x%x%x',
              '%s%p%x%d', '%.1024d', '%.1025d', '%.2048d', '%.2049d', '%.4096d', '%.4097d',
              '%99999999999s', '%08x', '%%20n', '%%20p', '%%20s', '%%20d', '%%20x', 
              '%#0123456x%08x%x%s%p%d%n%o%u%c%h%l%q%j%z%Z%t%i%e%g%f%a%C%S%08x%%', '\0xCD' x 50, '\0xCB' x 50); # 22

@numbers   = ('0', '-0', '1', '-1', '32767', '-32768', '2147483647', '-2147483647', '2147483648', '-2147483648',
              '4294967294', '4294967295', '4294967296', '357913942', '-357913942', '536870912', '-536870912', '5e-324', '1.79769313486231E+308', '3.39519326559384E-313',
	      '99999999999', '-99999999999', '0x100', '0x1000', '0x3fffffff', '0x7ffffffe', '0x7fffffff', '0x80000000', '0xffff', '0xfffffffe',
	      '0xfffffff', '0xffffffff', '0x10000', '0x100000', '0x99999999', '65535', '65536', '65537', '16777215', '16777216',
	      '16777217', '-268435455'); # 42

@miscbugs  = ('test|touch /tmp/FU_ZZ_ED|test', 'test`touch /tmp/FU_ZZ_ED`test', 'test\'touch /tmp/FU_ZZ_ED\'test', 'test;touch /tmp/FU_ZZ_ED;test', 'test&&touch /tmp/FU_ZZ_ED&&test',
	      'test|C:/WINDOWS/system32/calc.exe|test', 'test`C:/WINDOWS/system32/calc.exe`test', 'test\'C:/WINDOWS/system32/calc.exe\'test', 'test;C:/WINDOWS/system32/calc.exe;test', 'C:/WINDOWS/system32/calc.exe',
	      '|/bin/sh|', '`/bin/sh`', '../..\\' x 500, '%0xa', '%u000', '`~@#$', '%^&*()', '-=_+', '[]\{}', '|;\':"', 
	      ',./<>', '?' x 12000); # 22
# FUZZ DATA END HERE [_Jeremy Brown_ 3rd Generation Fuzzing Oracle [unlimited style, web] _Jeremy Brown_] 116

# DOM BEGIN
@domwindow    = ('outerHeight', 'outerWidth', 'status', 'moveBy', 'moveTo', 'resizeBy', 'resizeTo', 'scrollBy', 'scrollTo', 'setInterval', 'setTimeout'); # do <body onload="window.x=x"> (first 3) & others <body onload="window.x(x,x)"> -- window.resizeX/scrollX has 2 params & setX has 2
@domdocument  = ('cookie', 'getElementById', 'getElementsByName', 'getElementsByTagName', 'open', 'write', 'writeIn'); # open can have 2 params
@domhistory   = ('go');
@domlocation  = ('hash', 'host', 'hostname', 'href', 'pathname', 'port', 'protocol', 'search', 'assign', 'replace');
# DOM END

# HTML BEGIN
@htmlbody     = ('alink', 'background', 'bgcolor', 'link', 'text', 'vlink', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlp        = ('align', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlhr       = ('align', 'noshade', 'size', 'width', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlfont     = ('color', 'face', 'size', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlbdo      = ('dir', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlpre      = ('width', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmla        = ('charset', 'coords', 'href', 'hreflang', 'name', 'rel', 'rev', 'shape', 'target', 'type', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmllink     = ('charset', 'href', 'hrefland', 'media', 'rel', 'rev', 'target', 'type', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlframe    = ('frameborder', 'longdesc', 'marginheight', 'marginwidth', 'name', 'noresize', 'scrolling', 'src', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlframeset = ('cols', 'rows', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmliframe   = ('align', 'frameborder', 'height', 'longdesc', 'marginheight', 'marginwidth', 'name', 'scrolling', 'src', 'width', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlform     = ('action', 'accept', 'accept-charset', 'enctype', 'method', 'name', 'target', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlinput    = ('accept', 'align', 'alt', 'checked', 'disabled', 'maxlength', 'name', 'readonly', 'size', 'src', 'type', 'value', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmltextarea = ('cols', 'rows', 'disabled', 'name', 'readonly', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlbutton   = ('disabled', 'name', 'type', 'value', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlselect   = ('disabled', 'multiple', 'name', 'size', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmloptgroup = ('label', 'disabled', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmloption   = ('disabled', 'label', 'selected', 'value', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmllabel    = ('for', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmllegend   = ('align', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlul       = ('compact', 'type', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlol       = ('compact', 'start', 'type', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlli       = ('type', 'value', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmldir      = ('compact', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlmenu     = ('compact', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlimg      = ('alt', 'src', 'align', 'border', 'height', 'hspace', 'longdesc', 'usemap', 'vspace', 'width', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlmap      = ('id', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlarea     = ('alt', 'coords', 'href', 'nohref', 'shape', 'target', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmltable    = ('align', 'bgcolor', 'border', 'cellpadding', 'cellspacing', 'frame', 'rules', 'summary', 'width', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlcaption  = ('align', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlth       = ('abbr', 'align', 'axis', 'bgcolor', 'char', 'charoff', 'colspan', 'headers', 'height', 'nowrap', 'rowspan', 'scope', 'valign', 'width', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmltr       = ('align', 'bgcolor', 'char', 'charoff', 'valign', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmltd       = ('abbr', 'align', 'axis', 'bgcolor', 'char', 'charoff', 'colspan', 'headers', 'height', 'nowrap', 'rowspan', 'scope', 'valign', 'width', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlthead    = ('align', 'char', 'charoff', 'valign', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmltbody    = ('align', 'char', 'charoff', 'valign', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmltfoot    = ('align', 'char', 'charoff', 'valign', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlcol      = ('align', 'char', 'charoff', 'span', 'valign', 'width', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlcolgroup = ('align', 'char', 'charoff', 'span', 'valign', 'width', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlstyle    = ('type', 'media', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmldiv      = ('align', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlhead     = ('profile', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlmeta     = ('content', 'http-equiv', 'name', 'scheme', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlbase     = ('target', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlbasefont = ('color', 'face', 'size', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlscript   = ('type', 'charset', 'defer', 'language', 'src', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlapplet   = ('height', 'width', 'align', 'alt', 'archive', 'code', 'codebase', 'hspace', 'name', 'object', 'title', 'vspace', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlobject   = ('align', 'archive', 'border', 'classid', 'codebase', 'codetype', 'data', 'declare', 'height', 'hspace', 'name', 'standby', 'type', 'usemap', 'vspace', 'width', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
@htmlparam    = ('name', 'type', 'value', 'valuetype', 'class', 'id', 'style', 'title', 'dir', 'lang', 'accesskey', 'tabindex');
# HTML END


# JavaScript BEGIN
@jstlfuncs     = ('decodeURI', 'decodeURIComponent', 'encodeURI', 'encodeURIComponent', 'escape', 'unescape', 'eval', 'isFinite', 'inNaN', 'Number', 'parseFloat', 'parseInt', 'String');
@jsstringmtds  = ('strng.anchor', 'strng.charAt', 'strng.charCodeAt', 'strng.concat', 'strng.fontcolor', 'strng.fontsize', 'strng.fromCharCode', 'strng.indexOf', 'strng.lastIndexOf', 'strng.link',
		 'strng.link', 'strng.match', 'strng.replace', 'strng.search', 'strng.slice', 'strng.split', 'strng.substr', 'strng.substring');
@jsdatemtds    = ('Date.parse', 'dte.setDate', 'dte.setFullYear', 'dte.setHours', 'dte.setMilliseconds', 'dte.setMinutes', 'dte.setMonth', 'dte.Seconds', 'dte.setTime', 'dte.setUTCDate', 
		 'dte.setUTCMonth', 'dte.setUTCFullYear', 'dte.setUTCHours', 'dte.setUTCMinutes', 'dte.setUTCSeconds', 'dte.setUTCMilliseconds', 'dte.setYear');
@jsmathmtds    = ('Math.abs', 'Math.acos', 'Math.asin', 'Math.atan', 'Math.atan2', 'Math.ceil', 'Math.cos', 'Math.exp', 'Math.floor', 'Math.log', 'Math.max', 'Math.min',
		 'Math.pow', 'Math.round', 'Math.sin', 'Math.sqrt', 'Math.tan');
@jsnumbermtds  = ('numbr.toExponential', 'numbr.toFixed', 'numbr.toPercision', 'numbr.toString');
# JavaScript END

$cssbegin     = '<style type="text/css">';
$cssend       = '</style>' . "\n" . '</head>';

$htmlbegin    = '<html>';
$htmlend      = '</html>';

$scriptbegin  = '<script type="text/javascript">';
$scriptend    = '</script>';
$jsvarstrng   = 'var strng = "test";';
$jsvardte     = 'var dte = new Date();';
$jsvarnumbr   = 'var numbr = new Number(1000);';

$refresh1     = '<head><meta http-equiv="refresh" content="1; url=';
$refresh2     = '"></head>';

getopts('o:p:', \%opts);
$output  = $opts{'o'};
$phase   = $opts{'p'};

if(!defined($output) || !defined($phase))
{
     print "\n       Krakow Labs Development [krakowlabs.com] -> bf2";
     print "\n     \"Browser Fuzzer 2 -- The bugs cannot hide anymore\"";
     print "\n        rush\@KL (Jeremy Brown) [rush\@krakowlabs.com]\n";
     print "\n       Usage: $0 -o <output directory> -p [phase]\n";
     print "\n[phase   one]  ->  CSS Fuzzing  (Cascading Style Sheets, Inline Style, Core Parsing)";
     print "\n[phase   two]  ->  DOM Fuzzing  (Document Object Model, HTML/JS DOM Objects)";
     print "\n[phase three]  ->  HTML Fuzzing (HyperText Markup Language, Tags & Attributes)";
     print "\n[phase  four]  ->  JS Fuzzing   (JavaScript, Top Level Functions & Methods)";
     print "\n\nExample: $0 -o /var/www/apache2 -p 3 (now break out your favorite browser and fuzz it :)\n\n";
     exit(0);

}

     print "\n       Krakow Labs Development [krakowlabs.com] -> bf2";
     print "\n     \"Browser Fuzzer 2 -- The bugs cannot hide anymore\"";
     print "\n        rush\@KL (Jeremy Brown) [rush\@krakowlabs.com]\n";

$c = 1; $i = 1;

if($phase == '1')
{

     print "\nbf2[phase one] CSS Process Engaged. This could take some time (and disc space)!\n\n";

print "[STAGE-> $i] Writing <selector> fuzz data to $output\n";
foreach(@overflows)    { $fuzz = $_; csscreate1($output, $c, $htmlbegin, $refresh1, $cssbegin, $fuzz, $cssend, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; csscreate1($output, $c, $htmlbegin, $refresh1, $cssbegin, $fuzz, $cssend, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; csscreate1($output, $c, $htmlbegin, $refresh1, $cssbegin, $fuzz, $cssend, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; csscreate1($output, $c, $htmlbegin, $refresh1, $cssbegin, $fuzz, $cssend, $htmlend); $c++; } $i++;

print "[STAGE-> $i] Writing <property> fuzz data to $output\n";
foreach(@overflows)    { $fuzz = $_; csscreate2($output, $c, $htmlbegin, $refresh1, $cssbegin, $fuzz, $cssend, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; csscreate2($output, $c, $htmlbegin, $refresh1, $cssbegin, $fuzz, $cssend, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; csscreate2($output, $c, $htmlbegin, $refresh1, $cssbegin, $fuzz, $cssend, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; csscreate2($output, $c, $htmlbegin, $refresh1, $cssbegin, $fuzz, $cssend, $htmlend); $c++; } $i++;

print "[STAGE-> $i] Writing <value>    fuzz data to $output\n";
foreach(@overflows)    { $fuzz = $_; csscreate3($output, $c, $htmlbegin, $refresh1, $cssbegin, $fuzz, $cssend, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; csscreate3($output, $c, $htmlbegin, $refresh1, $cssbegin, $fuzz, $cssend, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; csscreate3($output, $c, $htmlbegin, $refresh1, $cssbegin, $fuzz, $cssend, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; csscreate3($output, $c, $htmlbegin, $refresh1, $cssbegin, $fuzz, $cssend, $htmlend); $c++; } $i++;

     $fcnt = $c-1;
     print "\nbf2[phase one] CSS Process Complete (Final Count: $fcnt). Point your browser to $output/css1.html and monitor for exceptions :)\n\n";

}

if($phase == '2')
{

     print "\nbf2[phase two] DOM Process Engaged. This could take some time (and disc space)!\n\n";

print "[STAGE-> $i] Writing <document> fuzz data to $output\n";
foreach(@domdocument)  { $object  = 'document'; $method = $_;
foreach(@overflows)    { $fuzz = $_; domcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $object, $method, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; domcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $object, $method, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; domcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $object, $method, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; domcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $object, $method, $fuzz, $scriptend, $htmlend); $c++; } } $i++;

print "[STAGE-> $i] Writing <window>   fuzz data to $output\n";
foreach(@domwindow)    { $object  = 'window'; $method = $_;
foreach(@overflows)    { $fuzz = $_; domcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $object, $method, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; domcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $object, $method, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; domcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $object, $method, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; domcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $object, $method, $fuzz, $scriptend, $htmlend); $c++; } } $i++;

print "[STAGE-> $i] Writing <history>  fuzz data to $output\n";
foreach(@domhistory)   { $object  = 'history'; $method = $_;
foreach(@overflows)    { $fuzz = $_; domcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $object, $method, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; domcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $object, $method, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; domcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $object, $method, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; domcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $object, $method, $fuzz, $scriptend, $htmlend); $c++; } } $i++;

print "[STAGE-> $i] Writing <location> fuzz data to $output\n";
foreach(@domlocation)  { $object  = 'location'; $method = $_;
foreach(@overflows)    { $fuzz = $_; domcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $object, $method, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; domcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $object, $method, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; domcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $object, $method, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; domcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $object, $method, $fuzz, $scriptend, $htmlend); $c++; } } $i++;

     $fcnt = $c-1;
     print "\nbf2[phase two] DOM Process Complete (Final Count: $fcnt). Point your browser to $output/dom1.html and monitor for exceptions :)\n\n";

}

if($phase == '3')
{

     print "\nbf2[phase three] HTML Process Engaged. This could take some time (and disc space)!\n\n";

print "[STAGE-> $i] Writing <body>     fuzz data to $output\n";
foreach(@htmlbody)     { $tag  = 'body'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE-> $i] Writing <p>        fuzz data to $output\n";
foreach(@htmlp)        { $tag  = 'p'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE-> $i] Writing <hr>       fuzz data to $output\n";
foreach(@htmlhr)       { $tag  = 'hr'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE-> $i] Writing <font>     fuzz data to $output\n";
foreach(@htmlfont)     { $tag  = 'font'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE-> $i] Writing <bdo>      fuzz data to $output\n";
foreach(@htmlbdo)      { $tag  = 'bdo'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE-> $i] Writing <pre>      fuzz data to $output\n";
foreach(@htmlpre)      { $tag  = 'pre'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE-> $i] Writing <a>        fuzz data to $output\n";
foreach(@htmla)        { $tag  = 'a'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE-> $i] Writing <link>     fuzz data to $output\n";
foreach(@htmllink)     { $tag  = 'link'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE-> $i] Writing <frame>    fuzz data to $output\n";
foreach(@htmlframe)    { $tag  = 'frame'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <iframe>   fuzz data to $output\n";
foreach(@htmliframe)   { $tag  = 'iframe'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <form>     fuzz data to $output\n";
foreach(@htmlform)     { $tag  = 'form'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <input>    fuzz data to $output\n";
foreach(@htmlinput)    { $tag  = 'input'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <textarea> fuzz data to $output\n";
foreach(@htmltextarea) { $tag  = 'textarea'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <button>   fuzz data to $output\n";
foreach(@htmlbutton)   { $tag  = 'button'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <select>   fuzz data to $output\n";
foreach(@htmlselect)   { $tag  = 'select'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <optgroup> fuzz data to $output\n";
foreach(@htmloptgroup) { $tag  = 'optgroup'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <option>   fuzz data to $output\n";
foreach(@htmloption)   { $tag  = 'option'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <label>    fuzz data to $output\n";
foreach(@htmllabel)    { $tag  = 'label'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <legend>   fuzz data to $output\n";
foreach(@htmllegend)   { $tag  = 'legend'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;;

print "[STAGE->$i] Writing <ul>       fuzz data to $output\n";
foreach(@htmlul)       { $tag  = 'ul'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <ol>       fuzz data to $output\n";
foreach(@htmlol)       { $tag  = 'ol'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <li>       fuzz data to $output\n";
foreach(@htmlli)       { $tag  = 'li'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <dir>      fuzz data to $output\n";
foreach(@htmldir)      { $tag  = 'dir'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <menu>     fuzz data to $output\n";
foreach(@htmlmenu)     { $tag  = 'menu'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <img>      fuzz data to $output\n";
foreach(@htmlimg)      { $tag  = 'img'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <map>      fuzz data to $output\n";
foreach(@htmlmap)      { $tag  = 'map'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <area>     fuzz data to $output\n";
foreach(@htmlarea)     { $tag  = 'area'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <table>    fuzz data to $output\n";
foreach(@htmltable)    { $tag  = 'table'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <caption>  fuzz data to $output\n";
foreach(@htmlcaption)  { $tag  = 'caption'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <th>       fuzz data to $output\n";
foreach(@htmlth)       { $tag  = 'th'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <tr>       fuzz data to $output\n";
foreach(@htmltr)       { $tag  = 'tr'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;;

print "[STAGE->$i] Writing <td>       fuzz data to $output\n";
foreach(@htmltd)       { $tag  = 'td'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <thead>    fuzz data to $output\n";
foreach(@htmlthead)    { $tag  = 'thead'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <tbody>    fuzz data to $output\n";
foreach(@htmltbody)    { $tag  = 'tbody'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <tfoot>    fuzz data to $output\n";
foreach(@htmltfoot)    { $tag  = 'tfoot'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <col>      fuzz data to $output\n";
foreach(@htmlcol)      { $tag  = 'col'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <colgroup> fuzz data to $output\n";
foreach(@htmlcolgroup) { $tag  = 'colgroup'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <style>    fuzz data to $output\n";
foreach(@htmlstyle)    { $tag  = 'style'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <div>      fuzz data to $output\n";
foreach(@htmldiv)      { $tag  = 'div'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <head>     fuzz data to $output\n";
foreach(@htmlhead)     { $tag  = 'head'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <meta>     fuzz data to $output\n";
foreach(@htmlmeta)     { $tag  = 'meta'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <base>     fuzz data to $output\n";
foreach(@htmlbase)     { $tag  = 'base'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <basefont> fuzz data to $output\n";
foreach(@htmlbasefont) { $tag  = 'basefont'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <script>   fuzz data to $output\n";
foreach(@htmlscript)   { $tag  = 'script'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <applet>   fuzz data to $output\n";
foreach(@htmlapplet)   { $tag  = 'applet'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <object>   fuzz data to $output\n";
foreach(@htmlobject)   { $tag  = 'object'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

print "[STAGE->$i] Writing <param>    fuzz data to $output\n";
foreach(@htmlparam)    { $tag  = 'param'; $attr = $_;
foreach(@overflows)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@fmtstring)    { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@numbers)      { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; }
foreach(@miscbugs)     { $fuzz = $_; htmlcreate($output, $c, $htmlbegin, $refresh1, $refresh2, $tag, $attr, $fuzz, $htmlend); $c++; } } $i++;

     $fcnt = $c-1;
     print "\nbf2[phase three] HTML Process Complete (Final Count: $fcnt). Point your browser to $output/html1.html and monitor for exceptions :)\n\n";

}

if($phase == '4')
{

     print "\nbf2[phase four] JS Process Engaged. This could take some time (and disc space)!\n\n";

print "[STAGE-> $i] Writing <jstlfuncs>     fuzz data to $output\n";
foreach(@jstlfuncs)     { $funcmthd = $_;
foreach(@overflows)     { $fuzz = $_; jscreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $jsvarstrng, $funcmthd, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@fmtstring)     { $fuzz = $_; jscreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $jsvarstrng, $funcmthd, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@numbers)       { $fuzz = $_; jscreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $jsvarstrng, $funcmthd, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@miscbugs)      { $fuzz = $_; jscreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $jsvarstrng, $funcmthd, $fuzz, $scriptend, $htmlend); $c++; } } $i++;

print "[STAGE-> $i] Writing <jsstringmthds> fuzz data to $output\n";
foreach(@jsstringmtds)  { $funcmthd = $_;
foreach(@overflows)     { $fuzz = $_; jscreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $jsvarstrng, $funcmthd, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@fmtstring)     { $fuzz = $_; jscreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $jsvarstrng, $funcmthd, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@numbers)       { $fuzz = $_; jscreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $jsvarstrng, $funcmthd, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@miscbugs)      { $fuzz = $_; jscreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $jsvarstrng, $funcmthd, $fuzz, $scriptend, $htmlend); $c++; } } $i++;

print "[STAGE-> $i] Writing <jsdatemthds>   fuzz data to $output\n";
foreach(@jsdatemtds)    { $funcmthd = $_;
foreach(@overflows)     { $fuzz = $_; jscreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $jsvardte, $funcmthd, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@fmtstring)     { $fuzz = $_; jscreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $jsvardte, $funcmthd, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@numbers)       { $fuzz = $_; jscreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $jsvardte, $funcmthd, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@miscbugs)      { $fuzz = $_; jscreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $jsvardte, $funcmthd, $fuzz, $scriptend, $htmlend); $c++; } } $i++;

print "[STAGE-> $i] Writing <jsmathmthds>   fuzz data to $output\n";
foreach(@jsmathmtds)    { $funcmthd = $_;
foreach(@overflows)     { $fuzz = $_; jscreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $jsvarstrng, $funcmthd, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@fmtstring)     { $fuzz = $_; jscreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $jsvarstrng, $funcmthd, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@numbers)       { $fuzz = $_; jscreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $jsvarstrng, $funcmthd, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@miscbugs)      { $fuzz = $_; jscreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $jsvarstrng, $funcmthd, $fuzz, $scriptend, $htmlend); $c++; } } $i++;

print "[STAGE-> $i] Writing <jsnumbermthds> fuzz data to $output\n";
foreach(@jsnumbermtds)  { $funcmthd = $_;
foreach(@overflows)     { $fuzz = $_; jscreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $jsvarnumbr, $funcmthd, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@fmtstring)     { $fuzz = $_; jscreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $jsvarnumbr, $funcmthd, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@numbers)       { $fuzz = $_; jscreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $jsvarnumbr, $funcmthd, $fuzz, $scriptend, $htmlend); $c++; }
foreach(@miscbugs)      { $fuzz = $_; jscreate($output, $c, $htmlbegin, $refresh1, $refresh2, $scriptbegin, $jsvarnumbr, $funcmthd, $fuzz, $scriptend, $htmlend); $c++; } } $i++;

     $fcnt = $c-1;
     print "\nbf2[phase four] JS Process Complete (Final Count: $fcnt). Point your browser to $output/js1.html and monitor for exceptions :)\n\n";

}

sub csscreate1 { #selector
		$ccoutput      = $_[0];
		$ccc           = $_[1];
		$cchtmlbegin   = $_[2];
		$ccrefresh     = $_[3];
		$cccssbegin    = $_[4];
		$ccfuzz        = $_[5];
		$cccssend      = $_[6];
		$cchtmlend     = $_[7];

     $ccfilename  = '>' . $ccoutput . '/' . 'css' . $ccc . '.html';
     $ccfnl       = $ccc + 1;
     $ccrefreshfn = 'css' . $ccfnl . '.html';

     $ccdata      = $cchtmlbegin . "\n" . $ccrefresh . $ccrefreshfn . '">' . "\n" . $cccssbegin . "\n" . $ccfuzz . ' {alink: blue}' . "\n" . $cccssend . "\n" . $cchtmlend;
     open(FILE, $ccfilename); print FILE $ccdata; close(FILE);
}

sub csscreate2 { # property
		$ccoutput      = $_[0];
		$ccc           = $_[1];
		$cchtmlbegin   = $_[2];
		$ccrefresh     = $_[3];
		$cccssbegin    = $_[4];
		$ccfuzz        = $_[5];
		$cccssend      = $_[6];
		$cchtmlend     = $_[7];

     $ccfilename  = '>' . $ccoutput . '/' . 'css' . $ccc . '.html';
     $ccfnl       = $ccc + 1;
     $ccrefreshfn = 'css' . $ccfnl . '.html';

     $ccdata      = $cchtmlbegin . "\n" . $ccrefresh . $ccrefreshfn . '">' . "\n" . $cccssbegin . "\n" . 'body {' . $ccfuzz . ': blue}' . "\n" . $cccssend . "\n" . $cchtmlend;
     open(FILE, $ccfilename); print FILE $ccdata; close(FILE);
}

sub csscreate3 { # value
		$ccoutput      = $_[0];
		$ccc           = $_[1];
		$cchtmlbegin   = $_[2];
		$ccrefresh     = $_[3];
		$cccssbegin    = $_[4];
		$ccfuzz        = $_[5];
		$cccssend      = $_[6];
		$cchtmlend     = $_[7];

     $ccfilename  = '>' . $ccoutput . '/' . 'css' . $ccc . '.html';
     $ccfnl       = $ccc + 1;
     $ccrefreshfn = 'css' . $ccfnl . '.html';

     $ccdata      = $cchtmlbegin . "\n" . $ccrefresh . $ccrefreshfn . '">' . "\n" . $cccssbegin . "\n" . 'body {alink: ' . $ccfuzz . '}' . "\n" . $cccssend . "\n" . $cchtmlend;
     open(FILE, $ccfilename); print FILE $ccdata; close(FILE);
}

sub domcreate {
		$dcoutput      = $_[0];
		$dcc           = $_[1];
		$dchtmlbegin   = $_[2];
		$dcrefresh1    = $_[3];
		$dcrefresh2    = $_[4];
		$dcscriptbegin = $_[5];
		$dcobject      = $_[6];
		$dcmethod      = $_[7];
		$dcfuzz        = $_[8];
		$dcscriptend   = $_[9];
		$dchtmlend     = $_[10];

     $dcfilename  = '>' . $dcoutput . '/' . 'dom' . $dcc . '.html';
     $dcfnl       = $dcc + 1;
     $dcrefreshfn = 'dom' . $dcfnl . '.html';

     $dcdata      = $dchtmlbegin . "\n" . $dcrefresh1 . $dcrefreshfn . $dcrefresh2 . "\n" . $dcscriptbegin . "\n" . $dctag . '.' . $dcattr . ' ="' . $dcfuzz . '";' . "\n" . $dcscriptend . "\n" . $dchtmlend;
     open(FILE, $dcfilename); print FILE $dcdata; close(FILE);
}

sub htmlcreate {
		 $hcoutput    = $_[0];
		 $hcc         = $_[1];
		 $hchtmlbegin = $_[2];
		 $hcrefresh1  = $_[3];
		 $hcrefresh2  = $_[4];
		 $hctag       = $_[5];
		 $hcattr      = $_[6];
		 $hcfuzz      = $_[7];
		 $hchtmlend   = $_[8];

     $hcfilename  = '>' . $hcoutput . '/' . 'html' . $hcc . '.html';
     $hcfnl       = $hcc + 1;
     $hcrefreshfn = 'html' . $hcfnl . '.html';

     $hcdata      = $hchtmlbegin . "\n" . $hcrefresh1 . $hcrefreshfn . $hcrefresh2 . "\n" . '<' . $hctag . ' ' . $hcattr . '="' . $hcfuzz . '">' . "\n" . $hchtmlend;
     open(FILE, $hcfilename); print FILE $hcdata; close(FILE);
}

sub jscreate {
	       $jcoutput      = $_[0];
	       $jcc           = $_[1];
               $jchtmlbegin   = $_[2];
	       $jcrefresh1    = $_[3];
	       $jcrefresh2    = $_[4];
	       $jcscriptbegin = $_[5];
	       $jcjsvar       = $_[6];
	       $jcfuncmthd    = $_[7];
	       $jcfuzz        = $_[8];
	       $jcscriptend   = $_[9];
	       $jchtmlend     = $_[10];

     $jcfilename  = '>' . $jcoutput . '/' . 'js' . $jcc . '.html';
     $jcfnl       = $jcc + 1;
     $jcrefreshfn = 'js' . $jcfnl . '.html';

     $jcdata      = $jchtmlbegin . "\n" . $jcrefresh1 . $jcrefreshfn . $jcrefresh2 . "\n" . $jcscriptbegin . "\n" . $jcjsvar . "\n" . $jcfuncmthd . '("' . $jcfuzz . '");' . "\n" . $jcscriptend . "\n" . $jchtmlend;
     open(FILE, $jcfilename); print FILE $jcdata; close(FILE);
}
